| mvhistMisc | R Documentation |
Utility functions for multivariate histograms
TallyHrep( x, H, report="summary" )
DrawPillars( S, height, shift=rep(0.0,3), ... )
HrepCones( S )
x |
data in an (n x d) matrix; rows are d-dimensional data vectors |
S |
(vps x d x nS) array of simplices in V representation, see |
H |
array of simplices in H representation, see |
report |
what information to return for tally |
height |
height of the pillars |
shift |
(x,y,z) shift of the pillars |
... |
Optional arguments to plot, e.g. color="red", etc. |
Internal functions for multivariate histograms.
TallyHrep tallies the number of data points in each simplex of the H representation.
DrawPillars plot 3d pillars/columns to show histogram height.
HrepCones computes an (m x (d+2) x ncones) array H, with H[,,k] giving the
H-representation of the k-th cone,
TallyHrep returns a list containing the number of data points in each simplex.
DrawPillars draws 3d pillars/columns to show histogram height.
HrepCones an (m x (d+2) x ncones) array H, with H[,,k] giving the
H-representation of the k-th cone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.