Utility functions for multivariate histograms
TallyHrep( x, H, report="summary" )
DrawPillars( S, height, shift=rep(0.0,3), ... )
HrepCones( S )TallyHrep returns a list containing the number of data points in each simplex.
DrawPillars draws 3d pillars/columns to show histogram height.
HrepCones an (m x (d+2) x ncones) array H, with H[,,k] giving the
H-representation of the k-th cone.
data in an (n x d) matrix; rows are d-dimensional data vectors
(vps x d x nS) array of simplices in V representation, see V2Hrep
array of simplices in H representation, see V2Hrep
what information to return for tally; one of "summary", "all", "none"
height of the pillars
(x,y,z) shift of the pillars
Optional arguments to plot, e.g. color="red", etc.
Internal functions for multivariate histograms.
TallyHrep tallies the number of data points in each simplex of the H representation.
DrawPillars plot 3d pillars/columns to show histogram height.
HrepCones computes an (m x (d+2) x ncones) array H, with H[,,k] giving the
H-representation of the k-th cone,